@@ -1,7 +1,7 @@
 import datetime
 import fnmatch
 import io
-from typing import Any, TextIO, Union
+from typing import Any, Generator, TextIO, Union
 
 import github
 import github.PullRequest
@@ -169,11 +169,25 @@ class Github(Base):
 
         SECRET_MASKER.add_secret(access_token)
 
-    def list_repositories(self) -> list[Repository]:
+    def list_repositories_with_open_pull_requests(
+        self,
+    ) -> Generator[Repository, None, None]:
+        user = self.client.get_user()
+        for issue in self.client.search_issues(
+            f"is:open is:pr author:{user.login} archived:false"
+        ):
+            yield GithubRepository(self.access_token, issue.repository)
+
+    def list_repositories(self, since: datetime.datetime) -> list[Repository]:
         log.debug("start fetching repositories")
         repos: list[Repository] = []
-        for gh_repo in self.client.get_user().get_repos():
-            repos.append(GithubRepository(self.access_token, gh_repo))
+        for gh_repo in self.client.get_user().get_repos(
+            direction="desc", sort="updated"
+        ):
+            if gh_repo.updated_at > since:
+                repos.append(GithubRepository(self.access_token, gh_repo))
+            else:
+                break
 
         log.debug("finished fetching repositories")
         return repos
